@@ -25,7 +25,6 @@
 #include <gnu_gama/model.h>
 #include <gnu_gama/pointbase.h>
 #include <gnu_gama/obsdata.h>
-#include <gnu_gama/list.h>
 #include <gnu_gama/ellipsoids.h>
 #include <gnu_gama/g3/g3_point.h>
 #include <gnu_gama/g3/g3_observation.h>
@@ -49,11 +48,11 @@ namespace GNU_gama {
     Model();
     virtual ~Model();
 
-    typedef GNU_gama::ObservationData<g3::Observation>  ObservationData;
-    typedef GNU_gama::List<Observation*>                ObservationList;
-    typedef GNU_gama::PointBase<g3::Point>              PointBase;
-    typedef GNU_gama::List<Parameter*>                  ParameterList;
-    typedef GNU_gama::Adj                               Adj;
+    using ObservationData = GNU_gama::ObservationData<g3::Observation>;
+    using ObservationList = std::list<Observation*>;
+    using PointBase       = GNU_gama::PointBase<g3::Point>;
+    using ParameterList   = std::list<Parameter*>;
+    using Adj             = GNU_gama::Adj;             
 
 
     PointBase           *points;
@@ -96,14 +95,14 @@ namespace GNU_gama {
     void linearization(XYZ*        );
     void linearization(ZenithAngle*);
 
-    void write_xml_adjusted(std::ostream&, const Angle*,      Index);
-    void write_xml_adjusted(std::ostream&, const Azimuth*,    Index);
-    void write_xml_adjusted(std::ostream&, const Distance*,   Index);
-    void write_xml_adjusted(std::ostream&, const Vector*,     Index);
-    void write_xml_adjusted(std::ostream&, const Height*,     Index);
-    void write_xml_adjusted(std::ostream&, const HeightDiff*, Index);
-    void write_xml_adjusted(std::ostream&, const XYZ*,        Index);
-    void write_xml_adjusted(std::ostream&, const ZenithAngle*,Index);
+    void write_xml_adjusted(std::ostream&, const Angle*,      int);
+    void write_xml_adjusted(std::ostream&, const Azimuth*,    int);
+    void write_xml_adjusted(std::ostream&, const Distance*,   int);
+    void write_xml_adjusted(std::ostream&, const Vector*,     int);
+    void write_xml_adjusted(std::ostream&, const Height*,     int);
+    void write_xml_adjusted(std::ostream&, const HeightDiff*, int);
+    void write_xml_adjusted(std::ostream&, const XYZ*,        int);
+    void write_xml_adjusted(std::ostream&, const ZenithAngle*,int);
 
     void set_algorithm(Adj::algorithm a) { adj->set_algorithm(a); }
 
@@ -116,8 +115,8 @@ namespace GNU_gama {
 
     double standard_deviation() const { return std_deviation; }
     double standard_variance () const { return std_variance; }
-    double cov_xx(Index i, Index j) { return std_variance*adj->q_xx(i,j); }
-    double cov_bb(Index i, Index j) { return std_variance*adj->q_bb(i,j); }
+    double cov_xx(int i, int j) { return std_variance*adj->q_xx(i,j); }
+    double cov_bb(int i, int j) { return std_variance*adj->q_bb(i,j); }
 
     bool   graph_is_connected() const  { return dm_graph_is_connected; }
 
@@ -204,10 +203,10 @@ namespace GNU_gama {
 
     void write_xml_adjusted_stdev  (const char*,
                                     std::ostream&, const Observation*,
-                                    Index, Index);
+                                    int, int);
 
     void write_xml_adjusted_cov_xyz(std::ostream&, const Observation*,
-                                    Index);
+                                    int);
   };
 
 }}
