@@ -1,5 +1,6 @@
 /* GNU Gama -- adjustment of geodetic networks
-   Copyright (C) 1999, 2006, 2012, 2014, 2015, 2017  Ales Cepek <cepek@gnu.org>
+   Copyright (C) 1999, 2006, 2012, 2014, 2015, 2017, 2020
+                 Ales Cepek <cepek@gnu.org>
 
    This file is part of the GNU Gama C++ library.
 
@@ -344,7 +345,7 @@ namespace GNU_gama { namespace local
     double m_0_apr_;         // a priori reference standard deviation
     double konf_pr_;         // (confidence) probability
     double tol_abs_;         // tollerance for testing absolute terms
-    bool update_constrained_coordinates_;
+    bool update_constrained_coordinates_{true};
     enum ApEm_ { apriorni_, empiricka_ };
     ApEm_ typ_m_0_;          // type of reference standard deviation
 
