@@ -3,9 +3,13 @@
  * ==========================================================================
  */
 
-const char* version = "0.06";
+const char* version = "1.00";
 
 /* ---------------------------------------------------------------------------
+ *
+ * 1.00  2017-11-21
+ *
+ *       - include guard in ellipsoids.h without double undescores
  *
  * 0.06  2006-08-26
  *
@@ -284,8 +288,8 @@ void Parser::error(const char* message)
 
 void Parser::xml2h(ostream& out)
 {
-  out << "#ifndef GNU_gama___gama_ellipsoids__header_file_h\n"
-      << "#define GNU_gama___gama_ellipsoids__header_file_h\n\n"
+  out << "#ifndef GNU_gama_gama_ellipsoids_header_file_h\n"
+      << "#define GNU_gama_gama_ellipsoids_header_file_h\n\n"
       << "#include <gnu_gama/ellipsoid.h>\n\n"
       << "// This file was generated by GNU Gama (program ellipsoids_xml"
       << /* version << */ ") from\n"
